@@ -768,7 +768,7 @@ ErrorType LibzipPlugin::extractEntry(zip_t *archive, zip_int64_t index, const Ex
 
         // 保存文件路径，不同目录下的同名文件分开计数,文件解压结束后才添加计数，
         tempFilePathName = strFilePath + QDir::separator() + strTemp;   // 路径加截取后的文件名
-        if (m_mapLongName[tempFilePathName] >= 999 || options.bOpen == true) {
+        if (m_mapLongName[tempFilePathName] >= 999 ) {
             return ET_LongNameError;
         }
         bHandleLongName = true;
@@ -840,7 +840,7 @@ ErrorType LibzipPlugin::extractEntry(zip_t *archive, zip_int64_t index, const Ex
     QFileDevice::Permissions per = getPermissions(value);
 
     if (bIsDirectory) {     // 文件夹
-        if (NAME_MAX < QString(strFileName).toLocal8Bit().length())
+        if (PATH_MAX < QString(strFileName).toLocal8Bit().length())
             return ET_LongNameError;
 
         QDir dir;
