@@ -1,23 +1,7 @@
-/*
-* Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
-*
-* Author:     gaoxiang <gaoxiang@uniontech.com>
-*
-* Maintainer: gaoxiang <gaoxiang@uniontech.com>
-*
-* This program is free software: you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation, either version 3 of the License, or
-* any later version.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+// Copyright (C) 2019 ~ 2020 Uniontech Software Technology Co.,Ltd.
+// SPDX-FileCopyrightText: 2022 UnionTech Software Technology Co., Ltd.
+//
+// SPDX-License-Identifier: GPL-3.0-or-later
 
 #include "compressview.h"
 #include "datamodel.h"
@@ -402,7 +386,9 @@ void CompressView::slotRenameFile()
     RenameDialog dialog(this);
     // 获取重命名所需文件
     FileEntry entry = listSelEntry.first();
-    bool isRepeat = !sender()->property("repeat").isNull();
+    bool isRepeat = true;
+    if(sender())
+        isRepeat = !sender()->property("repeat").isNull();
     int iResult = dialog.showDialog(entry.strFullPath, entry.strAlias, entry.isDirectory, isRepeat);
     if (0 == m_iLevel) { // 如果是根目录，重命名缓存文件名
         if (1 == iResult) {     // 如果点击确定，重命名文件
@@ -413,6 +399,7 @@ void CompressView::slotRenameFile()
             QString strAlias = QFileInfo(dialog.getNewNameText()).fileName();
             if(strAlias == entry.strFileName || strAlias == entry.strAlias) { //名字与原来相同不做处理
                 qInfo() << entry.strAlias <<" | The name already exists. Level" << m_iLevel;
+                if(!sender()) return;
                 sender()->setProperty("repeat", "true");
                 slotRenameFile();
                 return;
@@ -421,6 +408,7 @@ void CompressView::slotRenameFile()
             for(FileEntry tmpentry: m_listEntry) {
                 if(tmpentry.isDirectory == entry.isDirectory && tmpentry.strFullPath.endsWith(strAliasEndPath)) {
                     qInfo() << entry.strFullPath << " | The name already exists。 Level" << m_iLevel;
+                    if(!sender()) return;
                     sender()->setProperty("repeat", "true");
                     slotRenameFile();
                     return;
@@ -441,6 +429,7 @@ void CompressView::slotRenameFile()
                 bool bRename = dir.rename(entry.strFullPath, dialog.getNewNameText());
                 if(!bRename) {
                     qInfo() << entry.strFullPath <<" | The name already exists. Level" << m_iLevel;
+                    if(!sender()) return;
                     sender()->setProperty("repeat", "true");
                     slotRenameFile();
                 }
@@ -449,6 +438,7 @@ void CompressView::slotRenameFile()
                 bool bRename = file.rename(dialog.getNewNameText());
                 if(!bRename) {
                     qInfo() << entry.strFullPath <<" | The name already exists. Level" << m_iLevel;
+                    if(!sender()) return;
                     sender()->setProperty("repeat", "true");
                     slotRenameFile();
                 }
